@@ -37,15 +37,15 @@ func (attr *HCLAttribute) Type() cty.Type {
 }
 
 func (attr *HCLAttribute) IsString() bool {
-	return attr.Value().Type() == cty.String
+	return !attr.Value().IsNull() && attr.Value().IsKnown() && attr.Value().Type() == cty.String
 }
 
 func (attr *HCLAttribute) IsNumber() bool {
-	return attr.Value().Type() == cty.Number
+	return !attr.Value().IsNull() && attr.Value().IsKnown() && attr.Value().Type() == cty.Number
 }
 
 func (attr *HCLAttribute) IsBool() bool {
-	return attr.Value().Type() == cty.Bool
+	return !attr.Value().IsNull() && attr.Value().IsKnown() && attr.Value().Type() == cty.Bool
 }
 
 func (attr *HCLAttribute) Value() (ctyVal cty.Value) {
@@ -128,10 +128,20 @@ func (attr *HCLAttribute) listContains(val cty.Value, stringToLookFor string, ig
 }
 
 func (attr *HCLAttribute) mapContains(checkValue interface{}, val cty.Value) bool {
+	valueMap := val.AsValueMap()
 	switch t := checkValue.(type) {
 	case map[interface{}]interface{}:
 		for k, v := range t {
-			valueMap := val.AsValueMap()
+			for key, value := range valueMap {
+				rawValue := getRawValue(value)
+				if key == k && evaluate(v, rawValue) {
+					return true
+				}
+			}
+		}
+		return false
+	case map[string]interface{}:
+		for k, v := range t {
 			for key, value := range valueMap {
 				rawValue := getRawValue(value)
 				if key == k && evaluate(v, rawValue) {
@@ -141,7 +151,6 @@ func (attr *HCLAttribute) mapContains(checkValue interface{}, val cty.Value) boo
 		}
 		return false
 	default:
-		valueMap := val.AsValueMap()
 		for key := range valueMap {
 			if key == checkValue {
 				return true
@@ -298,6 +307,10 @@ func (attr *HCLAttribute) IsTrue() bool {
 		val := attr.Value().AsString()
 		val = strings.Trim(val, "\"")
 		return strings.ToLower(val) == "true"
+	case cty.Number:
+		val := attr.Value().AsBigFloat()
+		f, _ := val.Float64()
+		return f > 0
 	}
 	return false
 }
