@@ -14,10 +14,11 @@ func evaluate(criteriaValue interface{}, testValue interface{}) bool {
 	switch t := criteriaValue.(type) {
 	case map[interface{}]interface{}:
 		if t[functionNameKey] != nil {
-			functionName := t[functionNameKey].(string)
-			if functions[functionName] != nil {
-				return functions[functionName](t[valueNameKey], testValue)
-			}
+			return executeFunction(t[functionNameKey].(string), t[valueNameKey], testValue)
+		}
+	case map[string]interface{}:
+		if t[functionNameKey] != nil {
+			return executeFunction(t[functionNameKey].(string), t[valueNameKey], testValue)
 		}
 	default:
 		return t == testValue
@@ -25,6 +26,13 @@ func evaluate(criteriaValue interface{}, testValue interface{}) bool {
 	return false
 }
 
+func executeFunction(functionName string, criteriaValues, testValue interface{}) bool {
+	if functions[functionName] != nil {
+		return functions[functionName](criteriaValues, testValue)
+	}
+	return false
+}
+
 func isAny(criteriaValues interface{}, testValue interface{}) bool {
 	switch t := criteriaValues.(type) {
 	case []interface{}:
@@ -33,6 +41,12 @@ func isAny(criteriaValues interface{}, testValue interface{}) bool {
 				return true
 			}
 		}
+	case []string:
+		for _, v := range t {
+			if v == testValue.(string) {
+				return true
+			}
+		}
 	}
 	return false
 }
